@@ -49,6 +49,7 @@
 #include "models/feedsproxymodel.h"
 #include "models/podcastsearchmodel.h"
 #include "models/queuemodel.h"
+#include "networkconnectionmanager.h"
 #include "settingsmanager.h"
 #include "storagemanager.h"
 #include "sync/sync.h"
@@ -78,7 +79,7 @@ int main(int argc, char *argv[])
     QGuiApplication app(argc, argv);
     qInstallMessageHandler(myMessageHandler);
     QLoggingCategory::setFilterRules(QStringLiteral("org.kde.*=true"));
-    QQuickStyle::setStyle(QStringLiteral("Material"));
+    QQuickStyle::setStyle(QStringLiteral("org.kde.breeze"));
 #else
     QApplication app(argc, argv);
     if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
@@ -121,7 +122,7 @@ int main(int argc, char *argv[])
                      QStringLiteral(KASTS_VERSION_STRING),
                      i18n("Podcast Player"),
                      KAboutLicense::GPL,
-                     i18n("© 2020-2023 KDE Community"));
+                     i18n("© 2020–2023 KDE Community"));
     about.addAuthor(i18n("Tobias Fella"), QString(), QStringLiteral("tobias.fella@kde.org"), QStringLiteral("https://tobiasfella.de"));
     about.addAuthor(i18n("Bart De Vries"), QString(), QStringLiteral("bart@mogwai.be"));
     about.setProgramLogo(QVariant(QIcon(QStringLiteral(":/logo.svg"))));
@@ -152,6 +153,7 @@ int main(int argc, char *argv[])
         return engine->toScriptValue(KAboutData::applicationData());
     });
     qmlRegisterSingletonInstance("org.kde.kasts", 1, 0, "Database", &Database::instance());
+    qmlRegisterSingletonInstance("org.kde.kasts", 1, 0, "NetworkConnectionManager", &NetworkConnectionManager::instance());
     qmlRegisterSingletonInstance("org.kde.kasts", 1, 0, "Fetcher", &Fetcher::instance());
     qmlRegisterSingletonInstance("org.kde.kasts", 1, 0, "DataManager", &DataManager::instance());
     qmlRegisterSingletonInstance("org.kde.kasts", 1, 0, "SettingsManager", SettingsManager::self());
