@@ -22,8 +22,10 @@ public:
         IdRole,
         ReadRole,
         NewRole,
+        FavoriteRole,
         ContentRole,
         FeedNameRole,
+        UpdatedRole,
     };
     Q_ENUM(Roles)
 
